@@ -1,6 +1,4 @@
-from dataclasses import dataclass
 from logging import getLogger
-import traceback
 
 import deeplabel.client
 from deeplabel.exceptions import InvalidCredentials
