@@ -48,7 +48,7 @@ class Gallery(DeeplabelBase):
     status: _LabelGalleryStatus
 
     @classmethod
-    def _from_search_params(
+    def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
     ) -> List["Gallery"]:
         resp = client.get("/projects/gallery", params=params)
@@ -58,7 +58,7 @@ class Gallery(DeeplabelBase):
     
     @classmethod
     def from_gallery_id(cls, gallery_id:str, client:"deeplabel.client.BaseClient")->"Gallery":
-        galleries = cls._from_search_params({"galleryId": gallery_id}, client)
+        galleries = cls.from_search_params({"galleryId": gallery_id}, client)
         if not len(galleries):
             raise InvalidIdError(
                 f"Failed to fetch gallery with galleryId  : {gallery_id}"
